# Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
# file Copyright.txt or https://cmake.org/licensing for details.

#.rst:
# Findpcre
# --------
#
# Find the pcre headers and libraries.
#
# This module reports information about the pcre
# installation in several variables.  General variables::
#
#   pcre_FOUND - true if the pcre headers and libraries were found
#   pcre_INCLUDE_DIRS - the directory containing the pcre headers
#   pcre_LIBRARIES - pcre libraries to be linked
#
# The following cache variables may also be set::
#
#   pcre_INCLUDE_DIR - the directory containing the pcre headers
#   pcre_LIBRARY - the pcre library (if any)
#

# Find include directory
find_path(pcre_INCLUDE_DIR
          NAMES "pcre.h"
          DOC "pcre include directory")
mark_as_advanced(pcre_INCLUDE_DIR)

# Find all pcre libraries
find_library(pcre_LIBRARY "pcre"
  DOC "pcre libraries (if not in the C library)")
mark_as_advanced(pcre_LIBRARY)
mark_as_advanced(pcre_DIR)

include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(pcre
                                  FOUND_VAR pcre_FOUND
                                  REQUIRED_VARS pcre_INCLUDE_DIR
                                  FAIL_MESSAGE "Failed to find pcre")

if(pcre_FOUND)
  set(pcre_INCLUDE_DIRS "${pcre_INCLUDE_DIR}")
  if(pcre_LIBRARY)
    set(pcre_LIBRARIES "${pcre_LIBRARY}")
  else()
    unset(pcre_LIBRARIES)
  endif()
endif()
